@@ -1,6 +1,6 @@
 # -*- encoding: utf-8 -*-
 
-from __future__ import print_function
+from __future__ import print_function, unicode_literals
 
 import io
 import time
@@ -113,7 +113,7 @@ class Config:
         "direct-reply = 3",
         "reply-to-self = false",
         "[markup]",
-        "options = strikethrough, autolink",
+        "options = strikethrough, autolink, fenced_code",
         "allowed-elements = ",
         "allowed-attributes = "
     ]
