@@ -1082,7 +1082,35 @@ define('app/i18n/it',{
     "date-year": "quest'anno\n{{ n }} anni fa"
 });
 
-define('app/i18n',["app/config", "app/i18n/de", "app/i18n/en", "app/i18n/fr", "app/i18n/ru", "app/i18n/it"], function(config, de, en, fr, ru, it) {
+define('app/i18n/eo',{
+    "postbox-text": "Tajpu komenton ĉi-tie (almenaŭ 3 signoj)",
+    "postbox-author": "Nomo (malnepra)",
+    "postbox-email": "Retadreso (malnepra)",
+    "postbox-website": "Retejo (malnepra)",
+    "postbox-submit": "Sendu",
+    "num-comments": "{{ n }} komento\n{{ n }} komentoj",
+    "no-comments": "Neniu komento ankoraŭ",
+    "comment-reply": "Respondu",
+    "comment-edit": "Redaktu",
+    "comment-save": "Savu",
+    "comment-delete": "Forviŝu",
+    "comment-confirm": "Konfirmu",
+    "comment-close": "Fermu",
+    "comment-cancel": "Malfaru",
+    "comment-deleted": "Komento forviŝita",
+    "comment-queued": "Komento en atendovico por kontrolo.",
+    "comment-anonymous": "Sennoma",
+    "comment-hidden": "{{ n }} kaŝitaj",
+    "date-now": "ĵus nun",
+    "date-minute": "antaŭ unu minuto\nantaŭ {{ n }} minutoj",
+    "date-hour": "antaŭ unu horo\nantaŭ {{ n }} horoj",
+    "date-day": "hieraŭ\nantaŭ {{ n }} tagoj",
+    "date-week": "lasta semajno\nantaŭ {{ n }} semajnoj",
+    "date-month": "lasta monato\nantaŭ {{ n }} monatoj",
+    "date-year": "lasta jaro\nantaŭ {{ n }} jaroj"
+});
+
+define('app/i18n',["app/config", "app/i18n/de", "app/i18n/en", "app/i18n/fr", "app/i18n/ru", "app/i18n/it", "app/i18n/eo"], function(config, de, en, fr, ru, it, eo) {
 
     
 
@@ -1091,6 +1119,7 @@ define('app/i18n',["app/config", "app/i18n/de", "app/i18n/en", "app/i18n/fr", "a
         case "en":
         case "de":
         case "it":
+        case "eo":
             return function(msgs, n) {
                 return msgs[n === 1 ? 0 : 1];
             };
@@ -1126,7 +1155,8 @@ define('app/i18n',["app/config", "app/i18n/de", "app/i18n/en", "app/i18n/fr", "a
         en: en,
         fr: fr,
         ru: ru,
-        it: it
+        it: it,
+        eo: eo
     };
 
     var plural = pluralforms(lang);
